registerElement('$variable_id', function() {
  refreshLink('$element_id', '$link_text');
});
